<?xml version="1.0"?>
<!--
  Split the input document into a master XML and sub-documents.
  The parameter 'level' is used to determine where to split the document,
  its value is a number and it points to a heading level.
  For example, if 'level' is 2 then the document will be split for each new 'heading2' element.

  @author  Jean-Baptiste Reure
  @version 11 April 2012
-->
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://saxon.sf.net/"
  xmlns:fn="http://www.pageseeder.com/function" xmlns:dec="java:java.net.URLDecoder" xmlns:enc="java:java.net.URLEncoder"
  exclude-result-prefixes="saxon fn dec enc">

  <xsl:include href="utils.xsl" />
  
  <!-- to create the document path -->
  <xsl:param name="prefix" />

  <xsl:param name="file" />
  <xsl:param name="level" />
  
  <xsl:variable name="tocTitle" select="concat($file,'-toc')" />
  <!-- level split documents upto this heading level -->
  <xsl:variable name="slevel" select="number($level)+1" />

  <xsl:output encoding="UTF-8" method="xml" indent="no" />

  <xsl:template match="/">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="title" />

  <xsl:template match="root">
    <xsl:processing-instruction name="stylesheet">
      <xsl:text>format="standard" config="master" title="</xsl:text>
      <xsl:value-of select="concat($file,' - Master')" />
      <xsl:text>"</xsl:text>
    </xsl:processing-instruction>
    <root>
      <properties>
        <property name="document-type">master</property>
        <xsl:copy-of select="properties/property[@name != 'document-type']"/>
      </properties>
 		  <section id="title">
			  <body/>
		  </section>
		  <section id="toc">
  		  <toc/>
		  </section>
      <section id="1" format="psxreflist">
        <body>
          <!-- title><xsl:value-of select="$file"/></title -->
          <xsl:for-each-group select="section[not(@id='title' or @id='toc')]" group-starting-with="section[body/*[number(substring-after(name(),'heading')) &lt; $slevel ]]">
            <xsl:variable name="heading"
                          select="if (starts-with(name(body/*[1]),'heading')) then name(body/*[starts-with(name(),'heading')][1]) else 'heading1'" />
            <xsl:variable name="subDocId"
                          select="count(preceding-sibling::section[body/*[number(substring-after(name(),'heading')) &lt; $slevel ]]) +
                                  count(body/*[1][starts-with(name(),'heading')])" />
            <xsl:variable name="documentTitle" select="fn:getdocumenttitle($prefix,$subDocId)" />
            
            <xsl:result-document href="{$documentTitle}">
            <!--xsl:result-document href="{enc:encode($documentTitle)}"-->
              <xsl:processing-instruction name="stylesheet">
                <xsl:text>format="standard"</xsl:text>
                <xsl:if test="starts-with(name(body/*[1]),'heading')">
                  <xsl:text> title="</xsl:text>
                  <xsl:value-of select="normalize-space(body/*[starts-with(name(),'heading')][1])" />
                  <xsl:text>"</xsl:text>
                </xsl:if>
              </xsl:processing-instruction>
              <root>
                <!-- title><xsl:value-of select="$file"/></title -->
                <xsl:copy-of select="current-group()" />
              </root>
            </xsl:result-document>

            <para>
              <xref frag="default" display="document" title="" type="Replace" reverselink="true"
                reversetitle="{enc:encode($file)}-master" reversetype="None" href="{enc:encode($documentTitle)}">
                <!--reversetitle="{$file}-master" reversetype="None" href="{$documentTitle}"-->
                <xsl:value-of select="body/*[text()!=''][1]" />
              </xref>
            </para>

          </xsl:for-each-group>
        </body>
      </section>
    </root>
  </xsl:template>

</xsl:stylesheet>
